@@ -2,15 +2,7 @@ import pandas as pd
 from .shaping_rules import (advanced_city_shaping,
                                      alpha3_to_alpha2_map, basic_city_shaping)
 
-
-def disambiguate(city_geocode_df, input_city, input_country_code):
-    if city_geocode_df.shape[0] == 1:
-        return city_geocode_df.iloc[0]
-
-    if len(input_country_code) == 2:
-        input_alpha2 = input_country_code
-    else:
-        input_alpha2 = alpha3_to_alpha2_map[input_country_code]
+def unfold(city_geocode_df):
     unfolded_df = city_geocode_df[['lat', 'lon']].copy(deep=True)
 
     unfolded_df['geo_point'] = city_geocode_df.apply(
@@ -28,10 +20,27 @@ def disambiguate(city_geocode_df, input_city, input_country_code):
         lambda row: row['CityGeocode'].country_alpha2, axis=1)
     unfolded_df['source'] = city_geocode_df.apply(
         lambda row: row['CityGeocode'].source, axis=1)
+    return(unfolded_df)
+
+
+def disambiguate(city_geocode_df, input_city, input_country_code):
+    if city_geocode_df.shape[0] == 1:
+        return city_geocode_df.iloc[0]
+
+    if len(input_country_code) == 2:
+        input_alpha2 = input_country_code
+    else:
+        input_alpha2 = alpha3_to_alpha2_map[input_country_code]
+
+    if 'CityGeocode' in city_geocode_df.columns:
+        unfolded_df = unfold(city_geocode_df)
+    else:
+        unfolded_df = city_geocode_df
+
 
     unfolded_df['shaped_city_basic'] = unfolded_df['city'].apply(
         lambda city: basic_city_shaping(city))
-
+        
     basic_matching_df = unfolded_df[unfolded_df['shaped_city_basic'] == basic_city_shaping(
         input_city)]
     if len(basic_matching_df) == 1:
